# PyBlueprintMaker

`PyBlueprintMaker` is a Python-based project scaffolding tool that helps you create well-organized project structures using best-practices, `fixtures`, `pytest`, and the Python Standard Library. With support for `basic` to `modular` folder configurations and comprehensive testing, PyBlueprintMaker is the ultimate solution for maintainable projects.

PyBlueprintMaker is easy to use and provides everything you need to get started quickly. Whether you're a seasoned developer or just getting started, PyBlueprintMaker is the perfect tool to help you streamline your workflow and create high-quality projects with ease.

With PyBlueprintMaker, you can create project structures that are optimized for performance, scalability, and maintainability. Our tool provides support for a wide range of configurations, including basic, intermediate, advanced, and extended folder structures, so you can choose the one that's right for your project.

PyBlueprintMaker also includes comprehensive testing support, with built-in pytest fixtures and support for all major testing frameworks. Our tool is fully customizable, with support for a wide range of plugins and add-ons that can help you take your projects to the next level.

So what are you waiting for? Try PyBlueprintMaker today and see how easy it is to create high-quality, maintainable projects in Python!

![scafolds](assets/scaffolds.jpeg)

## Why is File Structure Important?

A well-organized file structure is crucial for any software project. It makes your code easier to understand, navigate, and maintain. Following best practices for file structure ensures consistency across projects, which can be especially helpful when **collaborating** with others or when you revisit your project after some time.

## Best Practices

Some best practices for organizing Python projects include:

- Separating source code and test code into different folders.
- Using meaningful and descriptive names for files and folders.
- Including a `README.md` file to provide an overview and usage instructions.
- Adding a `LICENSE` file to specify the terms under which the project can be used.
- Grouping related files together, such as scripts for different project structures.

## Installation

You can install PyBlueprintMaker via `pip`:

```bash
pip install PyBlueprintMaker
```

## Usage

To use PyBlueprintMaker, run the following command:

`PyBlueprintMaker [output_path] [structure]`

Where output_path is the desired output path for the project structure and structure is the project structure to create. The supported structures are basic, intermediate, advanced, extended, or modular.

For example, to create a basic project structure in a folder named `my_project`, run the following command:

```
PyBlueprintMaker my_project basic
```

## Contributing

If you find any issues or have suggestions, feel free to open an issue or submit a pull request.

## License

PyBlueprintMaker is licensed under the [MIT License](LICENSE).

## Support

If you like this project, please consider sharing a coffee. ☕

<a href="https://www.buymeacoffee.com/patimejiaS" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-blue.png" alt="Buy Me A Coffee" style="height: 60px !important;width: 217px !important;" ></a>
